# Generic repository

[![Coverage Status for dev branch](https://coveralls.io/repos/github/francipvb/generic-repository/badge.svg?branch=develop)](https://coveralls.io/github/francipvb/generic-repository?branch=develop)
[![Coverage Status for main branch](https://coveralls.io/repos/github/francipvb/generic-repository/badge.svg?branch=main)](https://coveralls.io/github/francipvb/generic-repository?branch=main)

This package includes building blocks to apply repository pattern in your program.

## Usage

For extensive usage examples, please see the tests.

Documentation about all kind of repository implementations will be added later.
